# Summary of 4 files

### needs_group_size_reduction in 4 LFNs

| Transform | LFN | Job ID | Site | Peak Mem | Log URL(s) | Occurrences |
| --------- | --- | ------ | ---- | -------- | ---------- | ----------- |
| `248082` | `LFN:/lhcb/MC/2017/BEAUTY2XGAMMA.STRIP.DST/00112596/0000/00112596_00000001_1.beauty2xgamma.strip.dst` | 962969827 | **LCG.CERN.cern** (3) |  | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2017%2FLOG%2F00248082%2F0000&task_name=00000003) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2017%2FLOG%2F00248082%2F0000&task_name=00000002) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2017%2FLOG%2F00248082%2F0000&task_name=00000001) | 3 / 3 |
|  | `LFN:/lhcb/MC/2017/BEAUTY2XGAMMA.STRIP.DST/00112596/0000/00112596_00000003_1.beauty2xgamma.strip.dst` | 962969827 | **LCG.CERN.cern** (3) |  | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2017%2FLOG%2F00248082%2F0000&task_name=00000003) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2017%2FLOG%2F00248082%2F0000&task_name=00000002) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2017%2FLOG%2F00248082%2F0000&task_name=00000001) | 3 / 3 |
|  | `LFN:/lhcb/MC/2017/BEAUTY2XGAMMA.STRIP.DST/00112596/0000/00112596_00000008_1.beauty2xgamma.strip.dst` | 962969827 | **LCG.CERN.cern** (3) |  | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2017%2FLOG%2F00248082%2F0000&task_name=00000003) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2017%2FLOG%2F00248082%2F0000&task_name=00000002) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2017%2FLOG%2F00248082%2F0000&task_name=00000001) | 3 / 3 |
|  | `LFN:/lhcb/MC/2017/BEAUTY2XGAMMA.STRIP.DST/00112596/0000/00112596_00000009_1.beauty2xgamma.strip.dst` | 962969827 | **LCG.CERN.cern** (3) |  | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2017%2FLOG%2F00248082%2F0000&task_name=00000003) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2017%2FLOG%2F00248082%2F0000&task_name=00000002) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2017%2FLOG%2F00248082%2F0000&task_name=00000001) | 3 / 3 |
